* SPSS Syntax for Equivalence Tests.

*==============================================================================
* CITATION
* Pierce, S. J. (2011, November). Master Teacher Series--Using equivalence
*   tests to prove that groups don't differ: How to generate "evidence of
*   absence" rather than "absence of evidence". Demonstration session presented
*   at Evaluation 2011: Values and Valuing in Evaluation, the annual conference
*   of the American Evaluation Association, Anaheim, CA.

*==============================================================================.
* REVISION HISTORY:
* 10/28/2011: Steve started this file. 

*==============================================================================.
* SET THE WORKING FOLDER. This tells SPSS where to look for files and where to
* save them by default. Change the path to the folder where you put the files
* from the presentation.

CD "C:\Users\Steve\Documents\Professional\Presentations\AEA 2011".

*==============================================================================.
* IMPORT THE DATA. "Scenarios.txt" is a copy of the simulated data generated 
* with the R script "AEA_2011_Equivalence_Tests.R". You could also just 
* use GET DATA to open a standard SPSS data file if you have one. 

DATA LIST FILE= "Scenarios.txt"  free (",")
 / Scenario Group Score.

VARIABLE LABELS
 Scenario "Scenario" 
 Group "Group" 
 Score "Score" .

VALUE LABELS Group 0 "Control" 1 "Treatment". 
EXECUTE.

*==============================================================================.
* TURN ON SPLIT FILES. This makes it easy to get separate analyses for each
* each of the 4 scenarios illustrated in the "Interpreting CIs (TOST vs. t-test)" 
* slide from the presentation. If you had only one dataset, you would not need 
* this step. 

SORT CASES  BY Scenario.
SPLIT FILE LAYERED BY Scenario.

*------------------------------------------------------------------------------.
* Run the t-tests procedure to get the 90% CI for the difference between the 
* means (alpha = .10). This corresponds to a TOST equivalence test with 
* alpha = .05. Focus on the "Equal variances assumed" rows, since that's the
* way I was running things in R and what I used for the slides. 

T-TEST GROUPS=Group(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Score
  /CRITERIA=CI(.90).

*------------------------------------------------------------------------------.
* Run t-tests procedure again to get traditional 95% CI for the difference 
* between the means (alpha = .05). This corresponds to a regular two-tailed
* t-test for independent means.  Focus on the "Equal variances assumed" rows, 
* since that's the way I was running things in R and what I used for the slides. 

T-TEST GROUPS=Group(0 1)
  /MISSING=ANALYSIS
  /VARIABLES=Score
  /CRITERIA=CI(.95).

* TURN OFF SPLIT FILES.

SPLIT FILE OFF.

*==============================================================================.
* SAVE THE OUTPUT. 

OUTPUT SAVE OUTFILE = "AEA_2011_Equivalence_Tests.spv". 



